import AuthProvider from 'context/AuthProvider';
import { SnackbarProvider } from 'notistack';
import { BrowserRouter, Route, Routes } from 'react-router-dom';
import MyClients from 'views/pages/clients/MyClients';
import MyExercises from 'views/pages/exercises/MyExercises';
import LandingPage from 'views/pages/landing/LandingPage';
import NotFound from 'views/pages/not-found/NotFound';
import PageNotReady from 'views/pages/not-ready/PageNotReady';
import MyTrainings from 'views/pages/trainings/MyTrainings';
import('dayjs/locale/ru');

export default function App() {
    return (
        <AuthProvider>
            <SnackbarProvider
                autoHideDuration={3500}
                anchorOrigin={{
                    horizontal: 'right',
                    vertical: 'top'
                }}>
                {/* TODO: create separated Router component which provide lazy loading */}
                <BrowserRouter
                    future={{
                        v7_startTransition: true,
                        v7_relativeSplatPath: true
                    }}>
                    <Routes>
                        <Route path="/" element={<LandingPage />}></Route>
                        <Route path="/account/clients" element={<MyClients />}></Route>
                        <Route path="/account/exercises" element={<MyExercises />}></Route>
                        <Route path="/account/trainings" element={<MyTrainings />}></Route>
                        <Route path="/account/schedule" element={<PageNotReady />}></Route>
                        <Route path="*" element={<NotFound />}></Route>
                    </Routes>
                </BrowserRouter>
            </SnackbarProvider>
        </AuthProvider>
    );
}
