import { Button } from '@mui/material';
import authorizedIcon from 'assets/images/authorized-icon.svg';
import * as buttonClasses from 'components/common/Button/Button.module.css';
import PreparedDialog from 'components/common/Dialog/PreparedDialog';
import PreparedDialogContent from 'components/common/Dialog/PreparedDialogContent';
import ModalContainer from 'components/common/modal/ModalContainer';
import useAuth from 'hooks/useAuth';
import useAxiosPrivate from 'hooks/useAxiosPrivate';
import { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import * as backendUrl from 'services/backendUrl';
import * as roles from 'services/roles';
import SignInSection from './SignInSection';
import SignUpSection from './SignUpSection';

export default function AuthModal() {
    const navigate = useNavigate();
    const axiosPrivate = useAxiosPrivate();
    const [openModal, setOpenModal] = useState(false);
    const [selectedButton, setSelectedButton] = useState('signIn');
    const { auth, setAuth } = useAuth();

    useEffect(() => {
        if (auth?.accessToken && !auth?.userInfo) {
            const getUserInfo = async () => {
                await axiosPrivate
                    .get(`${backendUrl.currentUserInfoUrl}`)
                    .then((response) => {
                        setAuth({
                            ...auth,
                            ...{
                                role: roles.mentorRole.role,
                                userInfo: response.data
                            }
                        });
                    })
                    .catch((error) => {
                        console.log(error);
                    });
            };
            getUserInfo();
        }
    }, [auth, setAuth, axiosPrivate]);

    const handleCloseModal = () => {
        setOpenModal(false);
    };

    const handleClickToAccountButton = () => {
        navigate('/account/clients', { replace: false });
    };

    return (
        <>
            {auth?.userInfo?.first_name ? (
                <Button
                    onClick={handleClickToAccountButton}
                    className="flex flex-row justify-center items-center font-normal text-[var(--color-form-white)] text-3xl lg:text-lg  bg-[var(--color-contrast-blue)] rounded-2xl border-0 px-3 py-1 gap-x-2 hover:bg-[var(--color-thymeleaf)] hover:drop-shadow-xl">
                    <p className="p-0">{auth.userInfo.first_name}</p>
                    <img src={authorizedIcon} alt="User icon" />
                </Button>
            ) : (
                <Button
                    onClick={() => setOpenModal(true)}
                    className="flex flex-row justify-center items-center font-normal text-[var(--color-form-white)] text-3xl bg-[var(--color-contrast-blue)] rounded-2xl border-0 px-3 py-1 gap-x-2 hover:bg-[var(--color-thymeleaf)] hover:drop-shadow-lg">
                    войти
                </Button>
            )}
            <PreparedDialog
                open={openModal}
                onClose={handleCloseModal}
                scroll="body"
                aria-labelledby="scroll-dialog-title"
                aria-describedby="scroll-dialog-description">
                <PreparedDialogContent dividers={scroll === 'paper'}>
                    <div className="container">
                        <ModalContainer>
                            <div className="relative items-center mt-3">
                                <div className="flex flex-row justify-between">
                                    <div className="flex justify-center items-center gap-x-2">
                                        <Button
                                            className={
                                                'flex flex-row justify-center font-normal  ] rounded-xl border-solid  border-2  p-3  hover:text-[var(--color-form-white)] hover:border-[var(--color-thymeleaf)] hover:bg-[var(--color-thymeleaf)] ' +
                                                (selectedButton === 'signIn'
                                                    ? 'text-[var(--color-form-white)] bg-[var(--color-thymeleaf)] border-[var(--color-thymeleaf)]'
                                                    : 'bg-[var(--color-form-white) text-[var(--color-form-dark-black)] border-[var(--color-border-gray)]')
                                            }
                                            onClick={() => setSelectedButton('signIn')}>
                                            <span
                                                className={'material-symbols-outlined'.concat(
                                                    ' ',
                                                    buttonClasses.size24
                                                )}>
                                                login
                                            </span>
                                        </Button>
                                        <Button
                                            className={
                                                'flex flex-row justify-center font-normal  ] rounded-xl border-solid  border-2  p-3  hover:text-[var(--color-form-white)] hover:border-[var(--color-thymeleaf)] hover:bg-[var(--color-thymeleaf)] ' +
                                                (selectedButton === 'signUp'
                                                    ? 'text-[var(--color-form-white)] bg-[var(--color-thymeleaf)] border-[var(--color-thymeleaf)]'
                                                    : 'bg-[var(--color-form-white) text-[var(--color-form-dark-black)] border-[var(--color-border-gray)]')
                                            }
                                            onClick={() => setSelectedButton('signUp')}>
                                            <span
                                                className={'material-symbols-outlined'.concat(
                                                    ' ',
                                                    buttonClasses.size24
                                                )}>
                                                app_registration
                                            </span>
                                        </Button>
                                    </div>
                                </div>
                            </div>
                            {selectedButton === 'signIn' ? (
                                <SignInSection handleCloseModal={handleCloseModal} />
                            ) : (
                                <SignUpSection handleCloseModal={handleCloseModal} />
                            )}
                        </ModalContainer>
                    </div>
                </PreparedDialogContent>
            </PreparedDialog>
        </>
    );
}
