import { ExpandMore } from '@mui/icons-material';
import {
    Accordion,
    AccordionDetails,
    AccordionSummary,
    Box,
    Button,
    Typography
} from '@mui/material';
import InvitationFormModal from 'components/apps/invitation/InvitationFormModal';
import CustomDivider from 'components/common/CustomDivider/CustomDivider';
import useAxiosPrivate from 'hooks/useAxiosPrivate';
import { useEffect } from 'react';
import * as backendUrl from 'services/backendUrl';
import { useImmer } from 'use-immer';
import ClientCard from './ClientCard';
import ClientInfoModal from './ClientInfoModal';
import MentorCard from './mentor/MentorCard';

export default function Clients() {
    const [clients, setClients] = useImmer([]);
    const [mentors, setMentors] = useImmer([]);
    const axiosPrivate = useAxiosPrivate();
    const [selectedUser, setSelectedUser] = useImmer(undefined);
    const [isInvitationModalWindowOpen, setIsInvitationModalWindowOpen] = useImmer(false);

    useEffect(() => {
        if (clients.length === 0 || mentors.length === 0) {
            const getClients = async () => {
                await axiosPrivate
                    .get(`${backendUrl.clientsUrl}`)
                    .then((response) => {
                        setClients(response.data);
                    })
                    .catch((error) => {
                        console.log(error);
                    });
            };
            const getMentors = async () => {
                await axiosPrivate
                    .get(`${backendUrl.mentorsUrl}`)
                    .then((response) => {
                        setMentors(response.data);
                    })
                    .catch((error) => {
                        console.log(error);
                    });
            };
            getClients();
            getMentors();
        }
    }, []);

    return (
        <div className="flex flex-col border-4 border-slate-200 p-2 rounded-md">
            <ClientInfoModal
                selectedUser={selectedUser}
                setSelectedUser={setSelectedUser}
                isMentor={false}
            />
            <InvitationFormModal
                isOpenModal={isInvitationModalWindowOpen}
                setIsOpenModal={setIsInvitationModalWindowOpen}
            />
            <Accordion
                sx={{ p: 0 }}
                className="text-2xl md:text-lg bg-[var(--color-)] text-[var(--color-form-white)]">
                <AccordionSummary
                    sx={{ p: 0 }}
                    expandIcon={<ExpandMore />}
                    aria-controls="panel1-content"
                    id="panel1-header">
                    <Box px={3}>
                        <Typography color="secondary" variant="h4">
                            Мои клиенты
                        </Typography>
                    </Box>
                </AccordionSummary>
                <AccordionDetails>
                    {clients.length > 0 ? (
                        <div className="grid lg:grid-cols-2 gap-2 mb-1">
                            {clients.map((client) => (
                                <ClientCard
                                    client={client}
                                    onClick={() => setSelectedUser(client)}
                                    key={client.id}
                                />
                            ))}
                        </div>
                    ) : (
                        <div className="text-2xl md:text-lg text-center bg-[var(--color-contrast-blue)] text-[var(--color-form-white)] rounded-xl px-2 py-3 mb-2">
                            <p>Здесь пока что пусто. Проверьте ожидающие запросы.</p>
                        </div>
                    )}
                </AccordionDetails>
            </Accordion>
            <CustomDivider />
            <Accordion
                sx={{ p: 0 }}
                className="text-2xl md:text-lg bg-[var(--color-)] text-[var(--color-form-white)]">
                <AccordionSummary
                    sx={{ p: 0 }}
                    expandIcon={<ExpandMore />}
                    aria-controls="panel1-content"
                    id="panel1-header">
                    <Box px={3}>
                        <Typography color="secondary" variant="h4">
                            Мои тренеры
                        </Typography>
                    </Box>
                </AccordionSummary>
                <AccordionDetails>
                    <div className="flex flex-col mb-1">
                        {mentors.length > 0 && (
                            <div className="grid lg:grid-cols-2 gap-2 mb-3 lg:mb-2">
                                {mentors.map((mentor) => (
                                    <MentorCard
                                        mentor={mentor}
                                        onClick={() => setSelectedUser(mentor)}
                                        key={mentor.id}
                                    />
                                ))}
                            </div>
                        )}
                        <Button
                            className="bg-[var(--color-thymeleaf)] hover:animate-pulse text-white hover:transition-all hover:duration-200 rounded-xl size-full font-normal hover:shadow-[var(--color-thymeleaf)] hover:shadow-md p-2 normal-case"
                            onClick={() => setIsInvitationModalWindowOpen(true)}>
                            <p className="text-2xl lg:text-2xl">Присоединиться к тренеру</p>
                        </Button>
                    </div>
                </AccordionDetails>
            </Accordion>
        </div>
    );
}
