import CachedIcon from '@mui/icons-material/Cached';
import NotificationsActiveOutlinedIcon from '@mui/icons-material/NotificationsActiveOutlined';
import { IconButton } from '@mui/material';
import InvitationInfoModal from 'components/apps/invitation/InvitationInfoModal';
import useAuth from 'hooks/useAuth';
import { useEffect, useState } from 'react';
import { axiosPrivate } from 'services/axios';
import * as backendUrl from 'services/backendUrl';

export default function RightGridPartForClient() {
    const [isOpenInvitationModal, setIsOpenInvitationModal] = useState(false);
    const [clientInvitations, setClientInvitations] = useState([]);
    const { auth } = useAuth();

    useEffect(() => {
        axiosPrivate
            .get(`${backendUrl.invitationAllRequests}`)
            .then((response) => {
                const pendingInvitations = response.data.filter(
                    (element) => 'WAIT_RESPONSE' === element.status
                );
                setClientInvitations(pendingInvitations);
            })
            .catch((error) => {
                console.log(error);
            });
    }, [auth]);

    const handleClickOnReloadButton = () => {
        axiosPrivate
            .get(`${backendUrl.invitationAllRequests}`)
            .then((response) => {
                const pendingInvitations = response.data.filter(
                    (element) => 'WAIT_RESPONSE' === element.status
                );
                setClientInvitations(pendingInvitations);
            })
            .catch((error) => {
                console.log(error);
            });
    };

    return (
        <>
            {auth?.accessToken ? (
                <>
                    <InvitationInfoModal
                        clientInvitations={clientInvitations}
                        setClientInvitations={setClientInvitations}
                        isOpenInvitationModal={isOpenInvitationModal}
                        setIsOpenInvitationModal={setIsOpenInvitationModal}
                    />
                    <div className="flex flex-col justify-start lg:justify-self-end border-4 border-slate-200 p-2 rounded-md mt-1 lg:mt-0">
                        <div className="flex flex-col items-center">
                            <div className="flex flex-row justify-center items-center">
                                <IconButton
                                    aria-label="close"
                                    color="primary"
                                    onClick={() => setIsOpenInvitationModal(true)}>
                                    <NotificationsActiveOutlinedIcon fontSize="large" />
                                </IconButton>
                                <IconButton
                                    aria-label="close"
                                    color="primary"
                                    onClick={() => handleClickOnReloadButton()}>
                                    <CachedIcon fontSize="large" />
                                </IconButton>
                            </div>
                            <p className="text-2xl">{clientInvitations.length} уведомлений</p>
                        </div>
                    </div>
                </>
            ) : (
                <></>
            )}
        </>
    );
}
