import { ExpandMore } from '@mui/icons-material';
import { Accordion, AccordionDetails, AccordionSummary, Button, Typography } from '@mui/material';
import { Box } from '@mui/system';
import useAxiosPrivate from 'hooks/useAxiosPrivate';
import { useEffect, useState } from 'react';
import * as backendUrl from 'services/backendUrl';
import { useImmer } from 'use-immer';
import ExerciseCard from './ExerciseCard';
import ExerciseCreationModal from './ExerciseCreationModal';
import ExerciseInfoModal from './ExerciseInfoModal';

export default function Exercises() {
    const axiosPrivate = useAxiosPrivate();
    const [exercises, setExercises] = useState([]);
    const [openModalContent, setOpenModalContent] = useImmer(false);
    const [selectedExercise, setSelectedExercise] = useState(undefined);

    useEffect(() => {
        if (exercises.length === 0) {
            const getExercises = async () => {
                await axiosPrivate
                    .get(`${backendUrl.exercisesUrl}`)
                    .then((response) => {
                        setExercises(response.data);
                    })
                    .catch((error) => {
                        console.log(error);
                    });
            };
            getExercises();
        }
    }, []);

    return (
        <div className="flex flex-col border-4 border-slate-200 p-2 rounded-md">
            <ExerciseInfoModal
                selectedExercise={selectedExercise}
                setSelectedExercise={setSelectedExercise}
            />
            <ExerciseCreationModal
                isOpenModal={openModalContent}
                setIsOpenModal={setOpenModalContent}
            />
            <Accordion
                sx={{ p: 0 }}
                className="text-2xl md:text-lg bg-transparent text-[var(--color-form-white)]">
                <AccordionSummary
                    sx={{ p: 0 }}
                    expandIcon={<ExpandMore />}
                    aria-controls="panel1-content"
                    id="panel1-header">
                    <Box px={3}>
                        <Typography color="secondary" variant="h4">
                            Упражнения
                        </Typography>
                    </Box>
                </AccordionSummary>
                <AccordionDetails>
                    <div>
                        {exercises.length > 0 ? (
                            <div className="grid lg:grid-cols-2 gap-2 mb-1">
                                {exercises.map((exercise) => (
                                    <ExerciseCard
                                        key={exercise.name}
                                        exercise={exercise}
                                        onClick={() => setSelectedExercise(exercise)}
                                    />
                                ))}
                            </div>
                        ) : (
                            <></>
                        )}
                        <Button
                            className="bg-[var(--color-thymeleaf)] hover:animate-pulse text-white hover:transition-all hover:duration-200 rounded-xl size-full font-normal hover:shadow-[var(--color-thymeleaf)] hover:shadow-md p-2 mt-1 normal-case text-xl"
                            onClick={() => setOpenModalContent(true)}>
                            Добавить упражнение
                        </Button>
                    </div>
                </AccordionDetails>
            </Accordion>
        </div>
    );
}
