import useAuth from 'hooks/useAuth';
import useRefreshToken from 'hooks/useRefreshToken';
import { useEffect } from 'react';
import { axiosPrivate } from 'services/axios';
import * as backendUrl from 'services/backendUrl';
import * as roles from 'services/roles';

export default function useAxiosPrivate() {
    const refresh = useRefreshToken();
    const { auth, setAuth } = useAuth();

    useEffect(() => {
        const requestIntercept = axiosPrivate.interceptors.request.use(
            (config) => {
                if (!config.headers['Authorization']) {
                    config.headers['Authorization'] = `Bearer ${auth?.accessToken}`;
                }
                return config;
            },
            (error) => Promise.reject(error)
        );

        const responseIntercept = axiosPrivate.interceptors.response.use(
            (response) => {
                return response;
            },
            async (error) => {
                const prevRequest = error?.config;
                if (
                    (error?.response?.status === 401 || error?.response?.status === 403) &&
                    !prevRequest?.sent
                ) {
                    prevRequest.sent = true;
                    const newAccessToken = await refresh();
                    prevRequest.headers['Authorization'] = `Bearer ${newAccessToken}`;
                    return axiosPrivate(prevRequest);
                }
                return Promise.reject(error);
            }
        );

        if (auth?.accessToken && !auth?.userInfo) {
            const getUserInfo = async () => {
                await axiosPrivate
                    .get(`${backendUrl.currentUserInfoUrl}`)
                    .then((response) => {
                        setAuth({
                            ...auth,
                            ...{
                                role: roles.mentorRole.role,
                                userInfo: response.data
                            }
                        });
                    })
                    .catch((error) => {
                        console.log(error);
                    });
            };
            getUserInfo();
        }

        return () => {
            axiosPrivate.interceptors.request.eject(requestIntercept);
            axiosPrivate.interceptors.response.eject(responseIntercept);
        };
    }, [auth, setAuth, refresh]);
    return axiosPrivate;
}
